@@ -194,7 +194,7 @@ local nodes = {
 		description = S("Iron Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"default_glass.png^[colorize:#DEDEDE", "default_glass_detail.png^[colorize:#DEDEDE"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -205,7 +205,7 @@ local nodes = {
 		description = S("Coal Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"default_glass.png^[colorize:#828282", "default_glass_detail.png^[colorize:#828282"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -216,7 +216,7 @@ local nodes = {
 		description = S("Clean Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"moreblocks_clean_glass.png", "moreblocks_clean_glass_detail.png"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -316,7 +316,7 @@ local nodes = {
 		description = S("Trap Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"default_glass.png^moreblocks_trap_box_glass.png", "default_glass_detail.png"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -329,7 +329,7 @@ local nodes = {
 		description = S("Trap Obsidian Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"default_obsidian_glass.png^moreblocks_trap_box_glass.png", "default_obsidian_glass_detail.png"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -353,7 +353,7 @@ local nodes = {
 		description = S("Trap Clean Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"moreblocks_clean_glass.png^moreblocks_trap_box_glass.png", "moreblocks_clean_glass_detail.png"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -412,7 +412,7 @@ local nodes = {
 		description = S("Glow Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"default_glass.png^[colorize:#E9CD61", "default_glass_detail.png^[colorize:#E9CD61"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -424,7 +424,7 @@ local nodes = {
 		description = S("Clean Glow Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"moreblocks_clean_glass.png^[colorize:#E9CD61", "moreblocks_clean_glass_detail.png^[colorize:#E9CD61"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -436,7 +436,7 @@ local nodes = {
 		description = S("Trap Glow Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"default_glass.png^[colorize:#E9CD61^moreblocks_trap_box_glass.png", "default_glass_detail.png^[colorize:#E9CD61"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -450,7 +450,7 @@ local nodes = {
 		description = S("Trap Clean Glow Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"moreblocks_clean_glass.png^[colorize:#E9CD61^moreblocks_trap_box_glass.png", "moreblocks_clean_glass_detail.png^[colorize:#E9CD61"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -464,7 +464,7 @@ local nodes = {
 		description = S("Super Glow Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"default_glass.png^[colorize:#FFFF78", "default_glass_detail.png^[colorize:#FFFF78"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -476,7 +476,7 @@ local nodes = {
 		description = S("Clean Super Glow Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"moreblocks_clean_glass.png^[colorize:#FFFF78", "moreblocks_clean_glass_detail.png^[colorize:#FFFF78"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -488,7 +488,7 @@ local nodes = {
 		description = S("Trap Super Glow Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"default_glass.png^[colorize:#FFFF78^moreblocks_trap_box_glass.png", "default_glass_detail.png^[colorize:#FFFF78"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
@@ -502,7 +502,7 @@ local nodes = {
 		description = S("Trap Clean Super Glow Glass"),
 		drawtype = "glasslike_framed_optional",
 		tiles = {"moreblocks_clean_glass.png^[colorize:#FFFF78^moreblocks_trap_box_glass.png", "moreblocks_clean_glass_detail.png^[colorize:#FFFF78"},
-		use_texture_alpha = true,
+		use_texture_alpha = "clip",
 		paramtype = "light",
 		sunlight_propagates = true,
 		is_ground_content = false,
